@@ -14,13 +14,6 @@ MANIFEST_NAMES = ("__openerp__.py", "__manifest__.py")
 
 
 class ChecksOdooModule:
-    # TODO: Support check by version
-    # TODO: skip_files_ext skip check based on comment XML
-    # TODO: Support configuration file to set custom value for DFTL_ global variables
-    # TODO: Add autofix option and autofix the files
-    # TODO: ir.model.access.csv:5 Duplicate csv record ... in ir.model.access.csv:6
-    #       Use ir.model.access.csv:5 Duplicate csv record ... in line 6
-    # TODO: Use current directory for filename_short if it is not related with the repo
     def __init__(self, manifest_path, enable, disable, changed=None, verbose=True):
         if not os.path.isfile(manifest_path) or os.path.basename(manifest_path) not in MANIFEST_NAMES:
             raise UserWarning(  # pragma: no cover
@@ -151,6 +144,11 @@ def run(files_or_modules, enable=None, disable=None, no_verbose=False, no_exit=F
     # TODO: Add unnitest to check files filtered from pre-commit by hook
     # Uncommet to check what files sent pre-commit
     # open("/tmp/borrar.txt", "w").write(f"{len(files_or_modules)}\n{files_or_modules}")
+    if enable is None:
+        enable = set()
+    if disable is None:
+        disable = set()
+    exit_status = 0
     for manifest_path, changed in lookup_manifest_paths(files_or_modules).items():
         if not manifest_path:
             continue
@@ -160,15 +158,16 @@ def run(files_or_modules, enable=None, disable=None, no_verbose=False, no_exit=F
         for check in utils.getattr_checks(checks_obj, enable=enable, disable=disable):
             check()
         utils.filter_checks_enabled_disabled(checks_obj.checks_errors, enable, disable)
-        all_check_errors.append(checks_obj.checks_errors)
-    for check_errors in all_check_errors if not no_verbose else []:
-        for check_error, msgs in check_errors.items():
+        if checks_obj.checks_errors:
+            all_check_errors.append(checks_obj.checks_errors)
+            exit_status = 1
+        for check_error, msgs in checks_obj.checks_errors.items() if not no_verbose else {}:
             checks_obj.print(f"\n****{check_error}****")
             for msg in msgs:
                 checks_obj.print(f"{msg} - [{check_error}]")
     if no_exit:
         return all_check_errors
-    sys.exit(bool(all_check_errors))
+    sys.exit(exit_status)
 
 
 def main(**kwargs):
